Documentation
¶
Overview ¶
Package fsutil provides shared filesystem utilities.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AtomicWriteFile ¶
AtomicWriteFile writes data to a temp file and renames it into place, ensuring the write is atomic on POSIX filesystems.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.