fsutil

package
v0.15.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package fsutil provides shared filesystem utilities.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AtomicWriteFile

func AtomicWriteFile(path string, data []byte) error

AtomicWriteFile writes data to a temp file and renames it into place, ensuring the write is atomic on POSIX filesystems.

Types

This section is empty.

Jump to